@@ -36,7 +36,7 @@ exports.db = function (req, res) {
 }
 
 exports.jdbc = function (req, res) {
-    req.jdbc.query("mysql", "SELECT *  FROM  vet_ages", [], function (err, data) {
+    req.jdbc.query("mssql", "SELECT *  FROM  contract_type", [], function (err, data) {
         res.send(data);
     });
 }
@@ -85,7 +85,7 @@ exports.report = function (req, res) {
         department: "it"
     };
     var type = req.param("type");
-    req.logger.info(type);
+    //req.logger.info(type);
     res.ireport("report1.jasper", type, datas, parameters);
 }
 
